Performs an MX query for the domain name passed as parameter.
It actually uses the same methods a normal Resolver query would use, but automatically sort the results based on preferences and returns an ordered array.
# File 'lib/net/dns/resolver.rb', line 1030defmx(name,cls=Net::DNS::IN)arr=[]query(name,Net::DNS::MX,cls).answer.eachdo|entry|arr<<entryifentry.type=='MX'endarr.sort_by(&:preference)end